@@ -1,6 +1,6 @@
 """
-gameduino.prep
-^^^^^^^^^^^^^^
+gameduino.prep - for graphics and sound preparation
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
 The prep module provides utilities for
 preparing Gameduino media: images and sound.
@@ -8,7 +8,7 @@ These utilities can be used, for example, to take image files
 and encode them so that the Gameduino can display them as backgrounds
 or sprites.
 
-This module also defines useful constants for the sprite palette select field:
+This module defines mnemonics for the sprite palette select field:
 
 +-----------------------+-------+
 | PALETTE256A           | 0     |
@@ -19,13 +19,13 @@ This module also defines useful constants for the sprite palette select field:
 +-----------------------+-------+
 | PALETTE256D           | 3     |
 +-----------------------+-------+
-| PALETTE16A_BITS0123 = | 4     |
+| PALETTE16A_BITS0123   | 4     |
 +-----------------------+-------+
-| PALETTE16A_BITS4567 = | 6     |
+| PALETTE16A_BITS4567   | 6     |
 +-----------------------+-------+
-| PALETTE16B_BITS0123 = | 5     |
+| PALETTE16B_BITS0123   | 5     |
 +-----------------------+-------+
-| PALETTE16B_BITS4567 = | 7     |
+| PALETTE16B_BITS4567   | 7     |
 +-----------------------+-------+
 | PALETTE4A_BITS01      | 8     |
 +-----------------------+-------+
@@ -44,12 +44,17 @@ This module also defines useful constants for the sprite palette select field:
 | PALETTE4B_BITS67      | 15    |
 +-----------------------+-------+
 
-In addition the following palette values:
+In addition the four logical palette groups are defined for use with :meth:`ImageRAM.addsprites`:
 
-PALETTE4A = (PALETTE4A_BITS01, PALETTE4A_BITS23, PALETTE4A_BITS45, PALETTE4A_BITS67)
-PALETTE4B = (PALETTE4B_BITS01, PALETTE4B_BITS23, PALETTE4B_BITS45, PALETTE4B_BITS67)
-PALETTE16A = (PALETTE16A_BITS0123, PALETTE16A_BITS4567)
-PALETTE16B = (PALETTE16B_BITS0123, PALETTE16B_BITS4567)
++------------+------------------------------------------------------------------------+
+| PALETTE4A  | PALETTE4A_BITS01, PALETTE4A_BITS23, PALETTE4A_BITS45, PALETTE4A_BITS67 |
++------------+------------------------------------------------------------------------+
+| PALETTE4B  | PALETTE4B_BITS01, PALETTE4B_BITS23, PALETTE4B_BITS45, PALETTE4B_BITS67 |
++------------+------------------------------------------------------------------------+
+| PALETTE16A | PALETTE16A_BITS0123, PALETTE16A_BITS4567                               |
++------------+------------------------------------------------------------------------+
+| PALETTE16B | PALETTE16B_BITS0123, PALETTE16B_BITS4567                               |
++------------+------------------------------------------------------------------------+
 
 """
 
@@ -126,9 +131,13 @@ def rgb555(r, g, b):
 def rgba1555(r, g, b, a):
     return ((a < 128) << 15) + ((r / 8) << 10) + ((g / 8) << 5) + (b / 8)
 
-def binary(imdata):
-    # imdata is 8x8x4 RGBA character, string of length 256
-    # return the pixel data and palette data for it
+def encodech(imdata):
+    """
+    imdata is 8x8x4 RGBA character, string of length 256
+    return the pixel and palette data for it as
+    :class:`array.array` of type 'B' and 'H' respectively.
+    """
+
     assert len(imdata) == (4 * 8 * 8)
     (rgbs, palette) = rgbpal(imdata)
     indices = [palette.index(c) for c in rgbs]
@@ -220,7 +229,7 @@ def encode(im):
     pd = array('H', [0] * 4 * len(charset))
     for d,i in charset.items():
         for y in range(8):
-            (char, pal) = binary(d)
+            (char, pal) = encodech(d)
             cd[16 * i:16 * (i+1)] = array('B', char)
             pd[4 * i:4 * (i+1)] = pal
     return (picd, cd, pd)
@@ -399,7 +408,7 @@ class ImageRAM(object):
         for spr,spriteimage in enumerate(tiles):
             print >>self.hh, "case %d:" % spr
             for y in range((size[1] + 15) / 16):
-                for x in range((size[1] + 15) / 16):
+                for x in range((size[0] + 15) / 16):
                     t = get16x16(spriteimage, x, y)
                     t.info = im.info    # workaround: PIL does not copy .info when cropping
                     if isnonblank(t):
